@@ -10,6 +10,7 @@ import files_sdk.models.behavior as behavior
 import files_sdk.models.bundle as bundle
 import files_sdk.models.bundle_download as bundle_download
 import files_sdk.models.bundle_recipient as bundle_recipient
+import files_sdk.models.bundle_registration as bundle_registration
 import files_sdk.models.clickwrap as clickwrap
 import files_sdk.models.dns_record as dns_record
 import files_sdk.models.errors as errors
@@ -20,12 +21,16 @@ import files_sdk.models.file_comment as file_comment
 import files_sdk.models.file_comment_reaction as file_comment_reaction
 import files_sdk.models.file_upload_part as file_upload_part
 import files_sdk.models.folder as folder
+import files_sdk.models.form_field as form_field
+import files_sdk.models.form_field_set as form_field_set
 import files_sdk.models.group as group
 import files_sdk.models.group_user as group_user
 import files_sdk.models.history as history
 import files_sdk.models.history_export as history_export
 import files_sdk.models.history_export_result as history_export_result
 import files_sdk.models.image as image
+import files_sdk.models.inbox_registration as inbox_registration
+import files_sdk.models.inbox_upload as inbox_upload
 import files_sdk.models.invoice as invoice
 import files_sdk.models.invoice_line_item as invoice_line_item
 import files_sdk.models.ip_address as ip_address
@@ -68,6 +73,7 @@ from files_sdk.models.behavior import Behavior
 from files_sdk.models.bundle import Bundle
 from files_sdk.models.bundle_download import BundleDownload
 from files_sdk.models.bundle_recipient import BundleRecipient
+from files_sdk.models.bundle_registration import BundleRegistration
 from files_sdk.models.clickwrap import Clickwrap
 from files_sdk.models.dns_record import DnsRecord
 from files_sdk.models.errors import Errors
@@ -78,12 +84,16 @@ from files_sdk.models.file_comment import FileComment
 from files_sdk.models.file_comment_reaction import FileCommentReaction
 from files_sdk.models.file_upload_part import FileUploadPart
 from files_sdk.models.folder import Folder
+from files_sdk.models.form_field import FormField
+from files_sdk.models.form_field_set import FormFieldSet
 from files_sdk.models.group import Group
 from files_sdk.models.group_user import GroupUser
 from files_sdk.models.history import History
 from files_sdk.models.history_export import HistoryExport
 from files_sdk.models.history_export_result import HistoryExportResult
 from files_sdk.models.image import Image
+from files_sdk.models.inbox_registration import InboxRegistration
+from files_sdk.models.inbox_upload import InboxUpload
 from files_sdk.models.invoice import Invoice
 from files_sdk.models.invoice_line_item import InvoiceLineItem
 from files_sdk.models.ip_address import IpAddress
