@@ -7,7 +7,7 @@ class Automation:
     default_attributes = {
         'id': None,     # int64 - Automation ID
         'automation': None,     # string - Automation type
-        'trigger': None,     # string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
+        'trigger': None,     # string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, `email`, or `action`.
         'interval': None,     # string - If trigger is `daily`, this specifies how often to run this automation.  One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
         'next_process_on': None,     # string - If trigger is `daily`, date this automation will next run.
         'schedule': None,     # object - If trigger is `custom_schedule`, Custom schedule description for when the automation should be run.
@@ -20,6 +20,8 @@ class Automation:
         'user_ids': None,     # array - IDs of Users for the Automation (i.e. who to Request File from)
         'group_ids': None,     # array - IDs of Groups for the Automation (i.e. who to Request File from)
         'webhook_url': None,     # string - If trigger is `webhook`, this is the URL of the webhook to trigger the Automation.
+        'trigger_actions': None,     # string - If trigger is `action`, this is the list of action types on which to trigger the automation. Valid actions are create, read, update, destroy, move, copy
+        'trigger_action_path': None,     # string - If trigger is `action`, this is the path to watch for the specified trigger actions.
     }
 
     def __init__(self, attributes=None, options=None):
@@ -48,7 +50,9 @@ class Automation:
     #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
     #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
     #   schedule - object - Custom schedule for running this automation.
-    #   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
+    #   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, `email`, or `action`.
+    #   trigger_actions - array(string) - If trigger is `action`, this is the list of action types on which to trigger the automation. Valid actions are create, read, update, destroy, move, copy
+    #   trigger_action_path - string - If trigger is `action`, this is the path to watch for the specified trigger actions.
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -83,6 +87,10 @@ class Automation:
             raise InvalidParameterError("Bad parameter: group_ids must be an str")
         if "trigger" in params and not isinstance(params["trigger"], str):
             raise InvalidParameterError("Bad parameter: trigger must be an str")
+        if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+            raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
+        if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
+            raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
         response, _options = Api.send_request("PATCH", "/automations/{id}".format(id=params['id']), params, self.options)
         return response.data
 
@@ -177,7 +185,9 @@ def get(id, params = None, options = None):
 #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   schedule - object - Custom schedule for running this automation.
-#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
+#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, `email`, or `action`.
+#   trigger_actions - array(string) - If trigger is `action`, this is the list of action types on which to trigger the automation. Valid actions are create, read, update, destroy, move, copy
+#   trigger_action_path - string - If trigger is `action`, this is the path to watch for the specified trigger actions.
 def create(params = None, options = None):
     if "automation" in params and not isinstance(params["automation"], str):
         raise InvalidParameterError("Bad parameter: automation must be an str")
@@ -201,6 +211,10 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: schedule must be an dict")
     if "trigger" in params and not isinstance(params["trigger"], str):
         raise InvalidParameterError("Bad parameter: trigger must be an str")
+    if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+        raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
+    if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
+        raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
     if "automation" not in params:
         raise MissingParameterError("Parameter missing: automation")
     response, options = Api.send_request("POST", "/automations", params, options)
@@ -217,7 +231,9 @@ def create(params = None, options = None):
 #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   schedule - object - Custom schedule for running this automation.
-#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
+#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, `email`, or `action`.
+#   trigger_actions - array(string) - If trigger is `action`, this is the list of action types on which to trigger the automation. Valid actions are create, read, update, destroy, move, copy
+#   trigger_action_path - string - If trigger is `action`, this is the path to watch for the specified trigger actions.
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -248,6 +264,10 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: schedule must be an dict")
     if "trigger" in params and not isinstance(params["trigger"], str):
         raise InvalidParameterError("Bad parameter: trigger must be an str")
+    if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+        raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
+    if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
+        raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     if "automation" not in params:
