@@ -11,7 +11,11 @@ class FileComment:
         'path': None,     # string - File path.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -24,7 +28,7 @@ class FileComment:
 
     # Parameters:
     #   body (required) - string - Comment body.
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -43,7 +47,7 @@ class FileComment:
         response, _options = Api.send_request("PATCH", "/file_comments/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -58,7 +62,7 @@ class FileComment:
         response, _options = Api.send_request("DELETE", "/file_comments/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -69,23 +73,19 @@ class FileComment:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   path (required) - string - Path to operate on.
-def list_for(path, params = {}, options = {}):
+def list_for(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["path"] = path
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "path" in params and not isinstance(params["path"], str):
         raise InvalidParameterError("Bad parameter: path must be an str")
     if "path" not in params:
@@ -95,7 +95,7 @@ def list_for(path, params = {}, options = {}):
 # Parameters:
 #   body (required) - string - Comment body.
 #   path (required) - string - File path.
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "body" in params and not isinstance(params["body"], str):
         raise InvalidParameterError("Bad parameter: body must be an str")
     if "path" in params and not isinstance(params["path"], str):
@@ -109,9 +109,11 @@ def create(params = {}, options = {}):
 
 # Parameters:
 #   body (required) - string - Comment body.
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -124,9 +126,11 @@ def update(id, params = {}, options = {}):
     response, options = Api.send_request("PATCH", "/file_comments/{id}".format(id=params['id']), params, options)
     return FileComment(response.data, options)
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -135,7 +139,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/file_comments/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
